@@ -350,14 +350,13 @@ sub run {
     # or libtool.
     my $ltinbd  = $info->relation('build-depends-all')->implies($LIBTOOL);
     my %warned;
-    my $format = $info->field('format');
-
     # Assume the package to be non-native if the field is not present.
     # - while 1.0 is more likely in this case, Lintian will probably get
     #   better results by checking debfiles/ rather than looking for a diffstat
     #   that may not be present.
-    $format = '3.0 (quilt)' unless defined $format;
-    if ($format =~ /^\s*2\.0\s*\z/ or $format =~ /^\s*3\.0\s*\(quilt\)/) {
+    my $format = $info->field('format', '3.0 (quilt)');
+
+    if ($format =~ /^\s*2\.0\s*\z/ or $format =~ /^\s*3\.0\s*\(quilt|git\)/) {
         check_debian_dir($info, \%warned);
     }elsif (not $info->native) {
         check_diffstat($info->diffstat, \%warned);
@@ -644,6 +643,21 @@ sub find_cruft {
             close($fd);
         }
 
+        # .chm files are usually generated by non-free software
+        if (   $basename =~ /\.chm$/i
+            && $file_info eq 'MS Windows HtmlHelp Data'
+            && $entry->is_open_ok
+            && index($entry->file_contents, 'Halibut,') == -1) {
+            tag 'source-contains-prebuilt-ms-help-file', $name;
+        }
+
+        # Ensure we have a README.source for R data files
+        if (   $basename =~ m,\.(?:rda|Rda|rdata|Rdata|RData)$,
+            && $entry->is_file
+            && !$info->index_resolved_path('debian/README.source')) {
+            tag 'r-data-without-readme-source', $name;
+        }
+
         # Lena Söderberg image
         if ($basename =~ /\blenn?a\b/i) {
             if(    $file_info =~ /\bimage\b/i
@@ -693,6 +707,16 @@ sub find_cruft {
             }
         }
 
+        if (   $name =~ m{^debian/(README.source|copyright|rules|control)$}
+            && $entry->is_file
+            && $entry->is_open_ok) {
+            my $fd = $entry->open;
+            while (my $line = <$fd>) {
+                next unless $line =~ m/(?<!")(FIX_?ME)(?!")/;
+                tag 'file-contains-fixme-placeholder', "$name:$. $1";
+            }
+        }
+
         # Find mentioning of usr/lib/perl5 inside the packaging
         if ($name =~ m{^debian/}) {
             my $short = $entry->basename;
@@ -949,6 +973,11 @@ sub _search_in_block0 {
                 return;
             }
         }
+        # https://github.com/rafaelp/css_browser_selector is actually the
+        # original source. (#874381)
+        elsif ($block =~ m/css_browser_selector\(/) {
+            return;
+        }
         # now search hidden minified
         _linelength_test($entry, $info, $name, $basename, $dirname,$block);
     }
