@@ -80,8 +80,6 @@ our %known_tclxs
 our %known_tks
   = map { $_ => 1 } ('tk40', 'tk8.0', 'tk8.2', 'tk8.3', 'tk8.4', 'tk8.5',);
 
-our %known_tkxs = map { $_ => 1 } ('tkx8.2', 'tkx8.3',);
-
 our %known_libpngs = map { $_ => 1 } ('libpng12-0', 'libpng2', 'libpng3',);
 
 our @known_java_pkg = map { qr/$_/ } (
@@ -98,23 +96,12 @@ our @known_java_pkg = map { qr/$_/ } (
 );
 
 # Mapping of package names to section names
-my @NAME_SECTION_MAPPINGS = (
-    [qr/-docs?$/                      => 'doc'],
-    [qr/-dbg(?:sym)?$/                => 'debug'],
-    [qr/^(?:python-)?zope/            => 'zope'],
-    [qr/^python-/                     => 'python'],
-    [qr/^r-(?:cran|bioc|other)-/      => 'gnu-r'],
-    [qr/^lib.*-perl$/                 => 'perl'],
-    [qr/^lib.*-cil(?:-dev)?$/         => 'cli-mono'],
-    [qr/^lib.*-(?:java|gcj)$/         => 'java'],
-    [qr/^(?:lib)php-/                 => 'php'],
-    [qr/^lib(?:hugs|ghc6?)-/          => 'haskell'],
-    [qr/^lib.*-ruby(?:1\.\d)?$/       => 'ruby'],
-    [qr/^lib.*-(?:ocaml|camlp4)-dev$/ => 'ocaml'],
-    [qr/^lib.*-dev$/                  => 'libdevel'],
-    [qr/^gir\d+\.\d+-.*-\d+\.\d+$/    => 'introspection'],
-    [qr/^libjs-/                      => 'javascript'],
-);
+my $NAME_SECTION_MAPPINGS = Lintian::Data->new(
+    'fields/name_section_mappings',
+    qr/\s*=>\s*/,
+    sub {
+        return {'regex' =>  qr/$_[0]/x, 'section' => $_[1]};
+    });
 
 my %VCS_EXTRACT = (
     browser => sub { return @_;},
@@ -549,14 +536,18 @@ sub run {
             # Check package name <-> section.  oldlibs is a special case; let
             # anything go there.
             if ($parts[-1] ne 'oldlibs') {
-                foreach my $map (@NAME_SECTION_MAPPINGS) {
-                    next unless ($pkg =~ $map->[0]);
+                foreach my $name_section ($NAME_SECTION_MAPPINGS->all()) {
+                    my $regex = $NAME_SECTION_MAPPINGS->value($name_section)
+                      ->{'regex'};
+                    my $section = $NAME_SECTION_MAPPINGS->value($name_section)
+                      ->{'section'};
+                    next unless ($pkg =~ m{$regex});
 
                     my $area = '';
                     $area = "$parts[0]/" if (scalar @parts == 2);
                     tag 'wrong-section-according-to-package-name',
-                      "$pkg => ${area}$map->[1]"
-                      unless $parts[-1] eq $map->[1];
+                      "$pkg => ${area}$section"
+                      unless $parts[-1] eq $section;
                     last;
                 }
             }
@@ -570,9 +561,9 @@ sub run {
                 # Cannot use "unfold" as it could emit a tag for priority,
                 # which will be duplicated below.
                 $pri =~ s/\n//;
-                tag 'transitional-package-should-be-oldlibs-extra',
+                tag 'transitional-package-should-be-oldlibs-optional',
                   "$parts[-1]/$pri"
-                  unless $pri eq 'extra' && $parts[-1] eq 'oldlibs';
+                  unless $pri eq 'optional' && $parts[-1] eq 'oldlibs';
             }
         }
     }
@@ -588,11 +579,6 @@ sub run {
 
         tag 'unknown-priority', $priority
           unless $KNOWN_PRIOS->known($priority);
-
-        if ($pkg =~ /-dbg$/) {
-            tag 'debug-package-should-be-priority-extra', $pkg
-              unless $priority eq 'extra';
-        }
     }
 
     #---- Standards-Version
@@ -693,8 +679,10 @@ sub run {
             my $javadep = 0;
             unfold($field, \$data);
 
-            my (@seen_libstdcs, @seen_tcls, @seen_tclxs, @seen_tks, @seen_tkxs,
-                @seen_libpngs);
+            my (
+                @seen_libstdcs, @seen_tcls, @seen_tclxs,
+                @seen_tks, @seen_libpngs
+            );
 
             my $is_dep_field = sub {
                 any { $_ eq $_[0] }qw(depends pre-depends recommends suggests);
@@ -717,8 +705,6 @@ sub run {
                       if defined $known_tclxs{$alternatives[0][0]};
                     push @seen_tks, $alternatives[0][0]
                       if defined $known_tks{$alternatives[0][0]};
-                    push @seen_tkxs, $alternatives[0][0]
-                      if defined $known_tkxs{$alternatives[0][0]};
                     push @seen_libpngs, $alternatives[0][0]
                       if defined $known_libpngs{$alternatives[0][0]};
                 }
@@ -923,8 +909,6 @@ sub run {
               if (scalar @seen_tclxs > 1);
             tag 'package-depends-on-multiple-tk-versions', @seen_tks
               if (scalar @seen_tks > 1);
-            tag 'package-depends-on-multiple-tkx-versions', @seen_tkxs
-              if (scalar @seen_tkxs > 1);
             tag 'package-depends-on-multiple-libpng-versions', @seen_libpngs
               if (scalar @seen_libpngs > 1);
         }
@@ -989,7 +973,6 @@ sub run {
             qw(build-depends build-depends-indep build-depends-arch);
         };
 
-        my $restrictions_used = 0;
         my %depend;
         for my $field (
             qw(build-depends build-depends-indep build-depends-arch build-conflicts build-conflicts-indep build-conflicts-arch)
@@ -1022,10 +1005,6 @@ sub run {
                             }
                         }
 
-                        if (scalar @{$d_restr} >= 1) {
-                            $restrictions_used = 1;
-                        }
-
                         for my $restrlist (@{$d_restr}) {
                             for my $prof (@{$restrlist}) {
                                 $prof =~ s/^!//;
@@ -1165,21 +1144,6 @@ sub run {
             }
         }
 
-        # if restrictions are found in the build-depends/conflicts, then
-        # package must build-depend on dpkg (>= 1.17.14)
-        if ($restrictions_used) {
-            my $build_conflicts_all = $info->relation('build-conflicts-all');
-            tag 'restriction-formula-without-versioned-dpkg-dev-dependency'
-              unless ($build_all->implies('dpkg-dev (>= 1.17.14~)'));
-            # if the package uses debhelper then it must require
-            # version >= 9.20141010
-            if ($build_all->implies('debhelper')) {
-                tag
-'restriction-formula-with-debhelper-without-debhelper-version'
-                  unless ($build_all->implies('debhelper (>= 9.20141010~)'));
-            }
-        }
-
         my (@arch_dep_pkgs, @dbg_pkgs);
         foreach my $gproc ($group->get_binary_processables) {
             my $binpkg = $gproc->pkg_name;
@@ -1339,6 +1303,8 @@ sub run {
                     tag $tag, $parts[0], $canonicalized;
                 }
             }
+            tag 'vcs-browser-links-to-empty-view', $uri
+              if $vcs eq 'browser' and $uri =~ m%rev=0&sc=0%;
         }
     }
 
