@@ -467,7 +467,7 @@ sub run {
                 my $newpath  = $obs_data->{'newdir'};
                 my $moreinfo = $obs_data->{'moreinfo'};
                 tag 'package-installs-into-obsolete-dir',
-                  "$file : $oldpath -> $newpath (see also $moreinfo)";
+                  "$file : $oldpath -> $newpath $moreinfo";
             }
         }
 
@@ -531,6 +531,10 @@ sub run {
             elsif ($fname =~ m,^etc/gconf/schemas/\S,) {
                 tag 'package-installs-into-etc-gconf-schemas', $file;
             }
+            # ---------------- /etc/init
+            elsif ($fname =~ m,^etc/init/\S,) {
+                tag 'package-installs-deprecated-upstart-configuration', $file;
+            }
             # ---------------- /etc/init.d
             elsif ( $fname =~ m,^etc/init\.d/\S,
                 and $fname !~ m,^etc/init\.d/(?:README|skeleton)$,
@@ -743,19 +747,18 @@ sub run {
                 }
             }
 
-            # ---------------- /usr/lib/R/site-library
-            elsif ($fname =~ m,^usr/lib/R/site-library/\S,) {
-                if (   $file->is_file
-                    && $file =~ m,\.(?:rda|Rda|rdata|Rdata)$,
-                    && !$info->index_resolved_path('debian/README.source')) {
-                    tag 'r-data-without-readme-source', $file;
-                }
-            }
-
             # ---------------- /usr/lib/sgml
             elsif ($fname =~ m,^usr/lib/sgml/\S,) {
                 tag 'file-in-usr-lib-sgml', $file;
             }
+            # ---------------- /usr/lib/node
+            elsif ($fname =~ m,^usr/lib/nodejs/,) {
+                if ($fname eq 'usr/lib/nodejs/package.json') {
+                    tag 'node-package-install-in-nodejs-rootdir', $fname;
+                }elsif ($fname =~m,usr/lib/nodejs/[^/]*\.js$,) {
+                    tag 'node-package-install-in-nodejs-rootdir', $fname;
+                }
+            }
             # ---------------- perllocal.pod
             elsif ($fname =~ m,^usr/lib/perl.*/perllocal.pod$,) {
                 tag 'package-installs-perllocal-pod', $file;
@@ -1160,6 +1163,11 @@ sub run {
             tag 'package-contains-python-coverage-file', $file;
         }
 
+        # ---------------- .class (compiled Java files)
+        if ($fname =~ m,\.class$,o) {
+            tag 'package-installs-java-bytecode', $file;
+        }
+
         # ---------------- /usr/lib/site-python
         if ($fname =~ m,^usr/lib/site-python/\S,) {
             tag 'file-in-usr-lib-site-python', $file;
@@ -1258,7 +1266,7 @@ sub run {
             and not $fname =~ m{ \. (?:
                   # Common "non-license" file extensions...
                    el|[ch]|cc|p[ylmc]|[hu]i|p_hi|html|php|rb|xpm
-                     |png|jpe?g|gif|svg|dtd|mk|lisp
+                     |png|jpe?g|gif|svg|dtd|mk|lisp|yml
                ) \Z}xsm
             and not $fname=~ m,^usr/share/zope/Products/.*\.(?:dtml|pt|cpt)$,
             and not $fname =~ m,/under\S+License\.docbook$,
@@ -1311,6 +1319,8 @@ sub run {
         if (   $fname =~ m,^usr/share/doc/$ppkg/override\.[lL]intian(?:\.gz)?$,
             or $fname =~ m,^usr/share/lintian/overrides/$ppkg/.+,) {
             tag 'override-file-in-wrong-location', $file;
+        } elsif ($fname =~ m,^usr/share/lintian/overrides/(.+)/.+$,) {
+            tag 'override-file-in-wrong-package', $file if $1 ne $pkg;
         }
 
         # doxygen md5sum
@@ -2030,6 +2040,15 @@ sub _check_tag_url_privacy_breach {
         }
     }
 
+    # False positive
+    # legal.xml file of gnome
+    # could be replaced by a link to local file but not really a privacy breach
+    if(    $file->basename eq 'legal.xml'
+        && $tagattr eq 'link'
+        &&  $website =~ m{^creativecommons.org/licenses/}) {
+        return;
+    }
+
     # track well known site
     foreach my $breaker ($PRIVACY_BREAKER_WEBSITES->all) {
         my $value = $PRIVACY_BREAKER_WEBSITES->value($breaker);
@@ -2045,6 +2064,7 @@ sub _check_tag_url_privacy_breach {
             return;
         }
     }
+
     # generic case
     unless (exists $privacybreachhash->{'tag-generic-'.$website}){
         tag 'privacy-breach-generic', $file, "($url)";
