@@ -85,7 +85,7 @@ my $VERSIONED_INTERPRETERS
 # beginning of the command rather than checking whether the command is at the
 # beginning of a line.
 my $LEADINSTR
-  = '(?:(?:^|[`&;(|{])\s*|(?:if|then|do|while)\s+|env(?:\s+[[:alnum:]_]+=(?:\S+|\"[^"]*\"|\'[^\']*\'))*\s+)';
+  = '(?:(?:^|[`&;(|{])\s*|(?:if|then|do|while|!)\s+|env(?:\s+[[:alnum:]_]+=(?:\S+|\"[^"]*\"|\'[^\']*\'))*\s+)';
 my $LEADIN = qr/$LEADINSTR/;
 
 #forbidden command in maintainer scripts
@@ -231,7 +231,7 @@ sub script_tag {
 sub run {
     my ($pkg, undef, $info) = @_;
 
-    my (%executable, %ELF, %scripts);
+    my (%executable, %ELF, %scripts, %seen_helper_cmds);
 
     # no dependency for install-menu, because the menu package specifically
     # says not to depend on it.
@@ -349,6 +349,7 @@ sub run {
                 if (check_script_syntax($interpreter, $path)) {
                     script_tag('shell-script-fails-syntax-check', $filename);
                 }
+                check_script_uses_sensible_utils($path);
             }
         }
 
@@ -377,6 +378,10 @@ sub run {
             script_tag('interpreter-in-usr-local', $filename,"#!$interpreter");
         } elsif ($interpreter eq '/bin/env') {
             script_tag('script-uses-bin-env', $filename);
+        } elsif ($interpreter eq 'nodejs') {
+            script_tag('script-uses-deprecated-nodejs-location',$filename);
+            # Check whether we have correct dependendies on nodejs regardless.
+            $data = $INTERPRETERS->value('node');
         } elsif ($base =~ /^php/) {
             script_tag('php-script-with-unusual-interpreter',
                 $filename, "$interpreter");
@@ -537,11 +542,19 @@ sub run {
         $interpreter =~ m|([^/]*)$|;
         my $base = $1;
 
+        # tag for statistics
+        tag 'maintainer-script-interpreter', "control/$file", $interpreter;
+
         if ($interpreter eq '') {
             tag 'script-without-interpreter', "control/$file";
             next;
         }
 
+        if ($interpreter eq 'ELF') {
+            tag 'elf-maintainer-script', "control/$file";
+            next;
+        }
+
         tag 'interpreter-not-absolute', "control/$file", "#!$interpreter"
           unless ($interpreter =~ m|^/|);
 
@@ -609,16 +622,16 @@ sub run {
                 if (check_script_syntax("/bin/${base}", $path)) {
                     tag 'maintainer-shell-script-fails-syntax-check', $file;
                 }
+                check_script_uses_sensible_utils($path);
             }
         }
 
         # now scan the file contents themselves
         my $fd = $path->open;
 
-        my (
-            $saw_init, $saw_invoke, $saw_debconf,
-            $saw_bange, $saw_sete, $has_code
-        );
+        my ($saw_init, $saw_invoke, $saw_debconf,
+            $saw_bange, $saw_sete, $has_code,
+            $saw_statoverride_list, $saw_statoverride_add);
         my %warned;
         my $cat_string = '';
 
@@ -631,8 +644,10 @@ sub run {
             if (/\#DEBHELPER\#/) {
                 tag 'maintainer-script-has-unexpanded-debhelper-token', $file;
             }
-            if (/^# Automatically added by (\S+)/) {
+            if (/^# Automatically added by (\S+)\s*$/) {
                 my $dh_cmd = $1;
+                # dh_python puts a trailing ":", remove that.
+                $dh_cmd =~ s/:++$//g;
                 tag 'debhelper-autoscript-in-maintainer-scripts', $dh_cmd
                   if not $dh_cmd_substs{$dh_cmd}++;
             }
@@ -673,6 +688,17 @@ sub run {
                 $saw_sete = 1;
             }
 
+            if (m,$LEADIN(?:/usr/bin/)?dpkg-statoverride\s,) {
+                $saw_statoverride_add = $. if /--add/;
+                $saw_statoverride_list = 1 if /--list/;
+            }
+
+            if (m,$LEADIN(?:/usr/bin/)?dpkg-maintscript-helper\s(\S+),) {
+                my $cmd = $1;
+                $seen_helper_cmds{$cmd} = () unless $seen_helper_cmds{$cmd};
+                $seen_helper_cmds{$cmd}{$file} = 1;
+            }
+
             if (    m,[^\w](?:(?:/var)?/tmp|\$TMPDIR)/[^)\]}\s],
                 and not m/\bmks?temp\b/
                 and not m/\btempfile\b/
@@ -999,11 +1025,27 @@ sub run {
             }
         }
 
+        if ($saw_statoverride_add && !$saw_statoverride_list) {
+            tag 'unconditional-use-of-dpkg-statoverride',
+              "$file:$saw_statoverride_add";
+        }
+
         close($fd);
 
     }
     close($ctrl_fd);
 
+    for my $cmd (qw(rm_conffile mv_conffile symlink_to_dir)) {
+        next unless $seen_helper_cmds{$cmd};
+
+        # dpkg-maintscript-helper(1) recommends the snippets are in all
+        # maintainer scripts but they are not strictly required in prerm.
+        for my $file (qw(preinst postinst postrm)) {
+            tag 'missing-call-to-dpkg-maintscript-helper', "$file ($cmd)"
+              unless $seen_helper_cmds{$cmd}{$file};
+        }
+    }
+
     # If any of the maintainer scripts used a variable in the file or
     # diversion name normalise them all
     if ($expand_diversions) {
@@ -1113,13 +1155,6 @@ sub run {
         }
     }
 
-    my @entries = $info->changelog ? $info->changelog->data : ();
-
-    if (@entries == 1) {
-        tag 'new-package-should-not-package-python2-module', $pkg
-          if $pkg =~ /^python-.*(?<!-doc)$/;
-    }
-
     return;
 }
 
@@ -1241,6 +1276,20 @@ sub check_script_syntax {
     return $?;
 }
 
+sub check_script_uses_sensible_utils {
+    my ($path) = @_;
+    my $fd = $path->open;
+    while (<$fd>) {
+        if (m/${LEADIN}(?:select-editor|sensible-(?:browser|editor|pager))\b/){
+            tag 'script-needs-depends-on-sensible-utils',
+              $path->name, "(line $.)";
+            last;
+        }
+    }
+    close($fd);
+    return;
+}
+
 sub remove_comments {
     local $_;
 
